@@ -247,5 +247,9 @@ class SQLPickle(object):
         self._conn.close()
 
 
-
+    def __repr__(self):
+        if hasattr(self, "_no_unicode_strings"):
+            return repr(dict([(str(k), v) for k,v in self.items()]))
+        else:
+            return repr(dict(self.items()))
 
