@@ -135,6 +135,23 @@ class TestSQLPickle(unittest.TestCase):
         self.assertRaises(KeyError, p.pop, 'rtyu')
 
 
+
+    def test_repr(self):
+        """ does repr() work ok?
+        """
+        p = sqlitepickle.SQLPickle()
+        key, value = 'asdf', 'qwer'
+        p.save(key, value)
+        p.save('rtyu', 2)
+
+        # we have unicode strings as keys.  Only test on python2.x
+        import sys
+        if sys.version_info[0] == 2:
+            self.assertEquals(repr(p), "{u'rtyu': 2, u'asdf': 'qwer'}")
+
+        p._no_unicode_strings = True
+        self.assertEquals(repr(p), repr({"asdf":"qwer", "rtyu":2}))
+
     def xxtest_time(self):
         f = tempfile.NamedTemporaryFile()
         fname = f.name
